# Globygon

Find center of mass on the sphere.



[![DOI](https://zenodo.org/badge/379094847.svg)](https://zenodo.org/badge/latestdoi/379094847)

[![docs](https://readthedocs.org/projects/pip/badge/)](https://globygon.readthedocs.io/en/latest/globygon.html#globygon.Catalog.calculate_center_of_mass)

[![tests](https://travis-ci.com/didamarkovic/globygon.svg?branch=main)](https://travis-ci.com/github/didamarkovic/globygon)
